summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-09-16 10:12:17 -0500
committerGlenn Randers-Pehrson <glennrp at users.sourceforge.net>2015-09-16 10:19:29 -0500
commitbfc7affa0de2782237e0fb1e5e59db14f7698ef2 (patch)
treed67cfbbea7813fb593a5f2f5ea02231c0a656ae0
parentdba870122ca9d3a6d1587a52c177d48b5ff60ffb (diff)
downloadlibpng-bfc7affa0de2782237e0fb1e5e59db14f7698ef2.tar.gz
[libpng17] Imported from libpng-1.7.0beta65.tarv1.7.0beta65
-rw-r--r--ANNOUNCE13
-rw-r--r--CHANGES2
-rw-r--r--LICENSE4
-rw-r--r--README2
-rw-r--r--contrib/libtests/pngvalid.c6
-rw-r--r--contrib/pngminim/decoder/pngusr.dfa1
-rw-r--r--contrib/pngminim/preader/pngusr.dfa1
-rw-r--r--libpng-manual.txt6
-rw-r--r--libpng.314
-rw-r--r--libpngpf.32
-rw-r--r--png.52
-rw-r--r--png.c4
-rw-r--r--png.h10
-rw-r--r--pngconf.h2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/chunkhash.c2
17 files changed, 43 insertions, 32 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 38a24e694..47d1548d8 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.7.0beta65 - September 15, 2015
+Libpng 1.7.0beta65 - September 16, 2015
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -852,7 +852,7 @@ Version 1.7.0beta64 [July 26, 2015]
Belatedly added Mans Rullgard and James Yu to the list of Contributing
Authors.
-Version 1.7.0beta65 [September 15, 2015]
+Version 1.7.0beta65 [September 16, 2015]
Use nanosleep() instead of usleep() in contrib/gregbook/rpng2-x.c
because usleep() is deprecated (port from libpng16).
Fixed potential leak of png_pixels in contrib/pngminus/pnm2png.c
@@ -861,6 +861,15 @@ Version 1.7.0beta65 [September 15, 2015]
"libpng_autotools_extra" list in autogen.sh because it was causing a
false positive for missing files (bug report by Robert C. Seacord).
Fixed some bad links in the man page.
+ Renamed the arm subdirectory to contrib/neon.
+ Made minor fixes to the test scripts:
+ pngimage: add --list-combos pngunknown: add --strict to catch warnings
+ pngvalid-standard: remove the spurious --progressive read (compare with
+ pngvalid-progressive-standard!) (John Bowler).
+ Implemented a new chunk parse implementation that can be shared. It
+ is currently shared by the progressive reader and the sequential one
+ (but not yet by the writer) (John Bowler).
+ Implemented shared transform handling that is used throughout (John Bowler).
Send comments/corrections/commendations to png-mng-implement at lists.sf.net
(subscription required; visit
diff --git a/CHANGES b/CHANGES
index caa978719..f44d0fed6 100644
--- a/CHANGES
+++ b/CHANGES
@@ -5149,7 +5149,7 @@ Version 1.7.0beta64 [July 26, 2015]
Belatedly added Mans Rullgard and James Yu to the list of Contributing
Authors.
-Version 1.7.0beta65 [September 15, 2015]
+Version 1.7.0beta65 [September 16, 2015]
Use nanosleep() instead of usleep() in contrib/gregbook/rpng2-x.c
because usleep() is deprecated (port from libpng16).
Fixed potential leak of png_pixels in contrib/pngminus/pnm2png.c
diff --git a/LICENSE b/LICENSE
index c223d9315..d97560024 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.7.0beta65, July 26, 2015, are
+libpng versions 1.0.7, July 1, 2000, through 1.7.0beta65, September 16, 2015, are
Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.0.6
with the following individuals added to the list of Contributing Authors:
@@ -104,4 +104,4 @@ the additional disclaimers inserted at version 1.0.7.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-July 26, 2015
+September 16, 2015
diff --git a/README b/README
index 159ce6ba2..bbc4e8084 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.7.0beta65 - July 26, 2015 (shared library 17.0)
+README for libpng version 1.7.0beta65 - September 16, 2015 (shared library 17.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/contrib/libtests/pngvalid.c b/contrib/libtests/pngvalid.c
index a9bcae550..4c97151f2 100644
--- a/contrib/libtests/pngvalid.c
+++ b/contrib/libtests/pngvalid.c
@@ -5408,7 +5408,7 @@ test_size(png_modifier* const pm, png_byte const colour_type,
# ifdef PNG_READ_DEINTERLACE_SUPPORTED
# ifdef PNG_WRITE_INTERLACING_SUPPORTED
- /* Test both togeher: */
+ /* Test both together: */
standard_test(&pm->this, FILEID(colour_type, DEPTH(bdlo), 0/*palette*/,
PNG_INTERLACE_ADAM7, w, h, 0), 0/*do_interlace*/,
pm->use_update_info);
@@ -6601,8 +6601,8 @@ image_transform_png_set_tRNS_to_alpha_add(image_transform *this,
/* We don't know yet whether there will be a tRNS chunk, but we know that
* this transformation should do nothing if there already is an alpha
- * channel. In addition, afte the bug fix in 1.7.0, there is no longer any
- * action on a palette image.
+ * channel. In addition, after the bug fix in 1.7.0, there is no longer
+ * any action on a palette image.
*/
return
# if PNG_LIBPNG_VER >= 10700
diff --git a/contrib/pngminim/decoder/pngusr.dfa b/contrib/pngminim/decoder/pngusr.dfa
index 4f402721a..07ec253d5 100644
--- a/contrib/pngminim/decoder/pngusr.dfa
+++ b/contrib/pngminim/decoder/pngusr.dfa
@@ -36,5 +36,6 @@ option FLOATING_ARITHMETIC off
option SETJMP on
option STDIO on
option READ_EXPAND on
+option READ_DEINTERLACE on
option READ_STRIP_16_TO_8 on
option USER_LIMITS on
diff --git a/contrib/pngminim/preader/pngusr.dfa b/contrib/pngminim/preader/pngusr.dfa
index ac297f41b..37701c8e0 100644
--- a/contrib/pngminim/preader/pngusr.dfa
+++ b/contrib/pngminim/preader/pngusr.dfa
@@ -36,5 +36,6 @@ option STDIO on
option READ_bKGD on
option READ_GAMMA on
option READ_EXPAND on
+option READ_DEINTERLACE on
option READ_STRIP_16_TO_8 on
option READ_GRAY_TO_RGB on
diff --git a/libpng-manual.txt b/libpng-manual.txt
index a63b7dbef..edb1c9f4e 100644
--- a/libpng-manual.txt
+++ b/libpng-manual.txt
@@ -1,6 +1,6 @@
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.7.0beta65 - September 15, 2015
+ libpng version 1.7.0beta65 - September 16, 2015
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -11,7 +11,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.7.0beta65 - September 15, 2015
+ libpng versions 0.97, January 1998, through 1.7.0beta65 - September 16, 2015
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -5317,7 +5317,7 @@ Other rules can be inferred by inspecting the libpng source.
XVII. Y2K Compliance in libpng
-September 15, 2015
+September 16, 2015
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
diff --git a/libpng.3 b/libpng.3
index 3abb60e40..0b871e0f9 100644
--- a/libpng.3
+++ b/libpng.3
@@ -1,4 +1,4 @@
-.TH LIBPNG 3 "September 15, 2015"
+.TH LIBPNG 3 "September 16, 2015"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.7.0beta65
.SH SYNOPSIS
@@ -498,7 +498,7 @@ Following is a copy of the libpng-manual.txt file that accompanies libpng.
.SH LIBPNG.TXT
libpng-manual.txt - A description on how to use and modify libpng
- libpng version 1.7.0beta65 - September 15, 2015
+ libpng version 1.7.0beta65 - September 16, 2015
Updated and distributed by Glenn Randers-Pehrson
<glennrp at users.sourceforge.net>
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -509,7 +509,7 @@ libpng-manual.txt - A description on how to use and modify libpng
Based on:
- libpng versions 0.97, January 1998, through 1.7.0beta65 - September 15, 2015
+ libpng versions 0.97, January 1998, through 1.7.0beta65 - September 16, 2015
Updated and distributed by Glenn Randers-Pehrson
Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -5815,7 +5815,7 @@ Other rules can be inferred by inspecting the libpng source.
.SH XVII. Y2K Compliance in libpng
-September 15, 2015
+September 16, 2015
Since the PNG Development group is an ad-hoc body, we can't make
an official declaration.
@@ -6137,7 +6137,7 @@ possible without all of you.
Thanks to Frank J. T. Wojcik for helping with the documentation.
-Libpng version 1.7.0beta65 - September 15, 2015:
+Libpng version 1.7.0beta65 - September 16, 2015:
Initially created in 1995 by Guy Eric Schalnat, then of Group 42, Inc.
Currently maintained by Glenn Randers-Pehrson (glennrp at users.sourceforge.net).
@@ -6160,7 +6160,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.0.7, July 1, 2000, through 1.7.0beta65, September 15, 2015, are
+libpng versions 1.0.7, July 1, 2000, through 1.7.0beta65, September 16, 2015, are
Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.0.6
with the following individuals added to the list of Contributing Authors:
@@ -6254,7 +6254,7 @@ the additional disclaimers inserted at version 1.0.7.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-September 15, 2015
+September 16, 2015
.\" end of man page
diff --git a/libpngpf.3 b/libpngpf.3
index 96bbca491..089ea21bf 100644
--- a/libpngpf.3
+++ b/libpngpf.3
@@ -1,4 +1,4 @@
-.TH LIBPNGPF 3 "July 26, 2015"
+.TH LIBPNGPF 3 "September 16, 2015"
.SH NAME
libpng \- Portable Network Graphics (PNG) Reference Library 1.7.0beta65
(private functions)
diff --git a/png.5 b/png.5
index 011410698..833f443a2 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "August 11, 2015"
+.TH PNG 5 "September 16, 2015"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/png.c b/png.c
index 5bf584539..412c2003c 100644
--- a/png.c
+++ b/png.c
@@ -694,13 +694,13 @@ png_get_copyright(png_const_structrp png_ptr)
#else
# ifdef __STDC__
return PNG_STRING_NEWLINE \
- "libpng version 1.7.0beta65 - July 26, 2015" PNG_STRING_NEWLINE \
+ "libpng version 1.7.0beta65 - September 16, 2015" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2015 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE;
# else
- return "libpng version 1.7.0beta65 - July 26, 2015\
+ return "libpng version 1.7.0beta65 - September 16, 2015\
Copyright (c) 1998-2015 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.";
diff --git a/pngconf.h b/pngconf.h
index 8b5cf2192..589902280 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.7.0beta65, July 26, 2015
+ * libpng version 1.7.0beta65, September 16, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 232eed182..bac488db6 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.7.0beta65 - July 26, 2015
+libpng version 1.7.0beta65 - September 16, 2015
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 826493d4f..59793c168 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source
*
- * libpng version 1.7.0beta65 - July 26, 2015
+ * libpng version 1.7.0beta65 - September 16, 2015
*
* Copyright (c) 1998-2011 Glenn Randers-Pehrson
*
diff --git a/scripts/chunkhash.c b/scripts/chunkhash.c
index 895c0b812..6ca7d6a6e 100644
--- a/scripts/chunkhash.c
+++ b/scripts/chunkhash.c
@@ -11,7 +11,7 @@ static const struct
png_uint_32 name;
}
png_known_chunks[] =
-/* See scripts/chunkdesc.h for how this works: */
+/* See pngchunk.h for how this works: */
#define PNG_CHUNK_END(n, c1, c2, c3, c4, before, after)\
{ png_ ##n }
#define PNG_CHUNK(n, c1, c2, c3, c4, before, after)\
diff --git a/png.h b/png.h
index bfbde0ae4..762fef467 100644
--- a/png.h
+++ b/png.h
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
* libpng version 1.7.0beta65, July 26, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
@@ -12,7 +12,7 @@
* Authors and maintainers:
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
* libpng versions 0.97, January 1998, through 1.7.0beta65, July 26, 2015: Glenn
* See also "Contributing Authors", below.
*
* Note about libpng version numbers:
@@ -252,7 +252,7 @@
*
* This code is released under the libpng license.
*
* libpng versions 1.0.7, July 1, 2000, through 1.7.0beta65, July 26, 2015, are
* Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6
* with the following individuals added to the list of Contributing Authors:
@@ -361,7 +361,7 @@
* Y2K compliance in libpng:
* =========================
*
- * July 26, 2015
+ * September 16, 2015
*
* Since the PNG Development group is an ad-hoc body, we can't make
* an official declaration.
@@ -431,7 +431,7 @@
/* Version information for png.h - this should match the version in png.c */
#define PNG_LIBPNG_VER_STRING "1.7.0beta65"
#define PNG_HEADER_VERSION_STRING \
- " libpng version 1.7.0beta65 - July 26, 2015\n"
+ " libpng version 1.7.0beta65 - September 16, 2015\n"
#define PNG_LIBPNG_VER_SONUM 17
#define PNG_LIBPNG_VER_DLLNUM 17
@@ -1,7 +1,7 @@
/* png.h - header file for PNG reference library
*
- * libpng version 1.7.0beta65, July 26, 2015
+ * libpng version 1.7.0beta65, September 16, 2015
*
* Copyright (c) 1998-2015 Glenn Randers-Pehrson
@@ -12,7 +12,7 @@
* libpng versions 0.71, May 1995, through 0.88, January 1996: Guy Schalnat
* libpng versions 0.89, June 1996, through 0.96, May 1997: Andreas Dilger
- * libpng versions 0.97, January 1998, through 1.7.0beta65, July 26, 2015: Glenn
+ * libpng versions 0.97, January 1998, through 1.7.0beta65, September 16, 2015: Glenn
* See also "Contributing Authors", below.
*
@@ -252,7 +252,7 @@
* This code is released under the libpng license.
*
- * libpng versions 1.0.7, July 1, 2000, through 1.7.0beta65, July 26, 2015, are
+ * libpng versions 1.0.7, July 1, 2000, through 1.7.0beta65, September 16, 2015, are
* Copyright (c) 2000-2002, 2004, 2006-2015 Glenn Randers-Pehrson, and are
* distributed according to the same disclaimer and license as libpng-1.0.6